'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Semantyk 
Package | `semantyk`

Daniel Bakas Amuchastegui\
August 31, 2017

Copyright © Semantyk 2021. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

# From Import Declarations | Package Imports
from . import archive

# From Import Declarations | Module Imports
from .archive import *
